# -*- coding: UTF-8 -*-
#
# Получение лицензий из очереди
#

from artix.common import py2to3utils
from plugins import status
from plugins import writetofile
import logger
import tempfile
import os
import sys


def main(message):
    log = logger.getLogger()
    log.info('Считываем путь для сохранения лицензии')

    localPath = message.properties.get('localPath')
    if localPath is None:
        mess = 'Путь для сохранения лицензии не указан'
        log.warning(mess)
        return status.errorLicense, mess

    log.info('Путь для сохранения лицензии - %s' % py2to3utils.ensureStr(localPath))
    fileName = os.path.basename(localPath)
    fileDir = os.path.dirname(localPath)

    log.info('Считываем файл лицензии из тела сообщения')
    if sys.version_info[0] < 3:
        license = message.content
    else:
        license = message.content.decode("ASCII")
    if license is None:
        mess = 'Файл лицензии не указан в теле сообщения'
        log.warning(mess)
        return status.errorLicense, mess

    writetofile.main(license, fileDir, fileName)

    log.info('Считываем скрипт, который нужно выполнить после сохранения файла лицензии')
    script = message.properties.get('script')
    if script is None:
        mess = 'Скрипт применения лицензии не указан'
        log.warning(mess)
        return status.errorLicense, mess

    scriptDir = tempfile.gettempdir()
    scriptName = 'licenseScript.sh'
    writetofile.main(script, scriptDir, scriptName)
    log.info('Запускаем сохраненный скрипт для применения лицензии')
    if sys.version_info[0] < 3:
        result = os.spawnl(os.P_WAIT, os.path.join(scriptDir, scriptName), "")
    else:
        result = os.spawnl(os.P_WAIT, os.path.join(scriptDir, scriptName), "start")
    if result == 0:
        os.remove(os.path.join(scriptDir, scriptName))
        return status.OK, 'Файл лицензии применен'

    mess = 'Ошибка выполнения скрипта для применения лицензии'
    log.error(mess)
    return status.errorLicense, mess
